@@ -24,7 +24,7 @@ FILE_FORMATS = {
         '.mp3', '.flac', '.wav', '.m4a'
     },
     'Other': {
-        '.json', '.torrent', '.zip', '.rar', '.7z'
+        '.json', '.torrent', '.zip', '.rar', '.7z', '.torrent'
     }
 }
 
@@ -34,7 +34,7 @@ logger = logging.getLogger(__name__)
 
 
 async def sanitize(name: str) -> str:
-    return re.sub(r'[<>:"/\\|?*\']', "", name)
+    return re.sub(r'[<>:"/\\|?*\']', "", name).strip()
 
 
 async def log(text, style=Fore.WHITE) -> None:
