@@ -34,7 +34,7 @@ def parse_args():
     parser.add_argument("--exclude-audio", help="skip downloading of audio files", action="store_true")
     parser.add_argument("--exclude-other", help="skip downloading of images", action="store_true")
     parser.add_argument("--ignore-history", help="This ignores previous download history", action="store_true")
-    parser.add_argument("--separate-posts", help="Separates thotsbay scraping into folders by post number", action="store_true")
+    parser.add_argument("--separate-posts", help="Separates forum scraping into folders by post number", action="store_true")
     parser.add_argument("--leakednudes-username", type=str, help="username to login to leakednudes", default=None)
     parser.add_argument("--leakednudes-password", type=str, help="password to login to leakednudes", default=None)
     parser.add_argument("--socialmediagirls-username", type=str, help="username to login to socialmediagirls", default=None)
@@ -53,7 +53,9 @@ async def download_all(args: argparse.Namespace):
     await clear()
     await log(f"We are running version {VERSION} of Cyberdrop Downloader", Fore.WHITE)
     print_args = Namespace(**vars(args)).__dict__
-    print_args['thotsbay_password'] = '!REDACTED!'
+    print_args['leakednudes_password'] = '!REDACTED!'
+    print_args['socialmediagirls_password'] = '!REDACTED!'
+    print_args['simpcity_password'] = '!REDACTED!'
     logging.debug(f"Starting downloader with args: {print_args}")
     input_file = args.input_file
     if not input_file.is_file():
@@ -75,12 +77,12 @@ async def download_all(args: argparse.Namespace):
 
     leakednudes_auth = AuthData(args.leakednudes_username, args.leakednudes_password)
     socialmediagirls_auth = AuthData(args.socialmediagirls_username, args.socialmediagirls_password)
-    thotsbay_auth = AuthData(args.thotsbay_username, args.thotsbay_password)
+    simpcity_auth = AuthData(args.simpcity_username, args.simpcity_password)
     skip_data = SkipData(args.skip_hosts)
     excludes = {'videos': args.exclude_videos, 'images': args.exclude_images, 'audio': args.exclude_audio,
                 'other': args.exclude_other}
     content_object = await scrape(links, client, args.include_id, leakednudes_auth, socialmediagirls_auth,
-                                  thotsbay_auth, args.separate_posts, skip_data)
+                                  simpcity_auth, args.separate_posts, skip_data)
 
     if await content_object.is_empty():
         logging.error('ValueError No links')
